@@ -40,7 +40,7 @@ BEGIN
     require Siffra::Base;
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION = '0.19';
+    $VERSION = '0.20';
     @ISA     = qw(Siffra::Base Exporter);
 
     #Give a hoot don't pollute, do not export more than needed by default
@@ -436,6 +436,7 @@ sub parseCSV()
     my ( $self, %parameters ) = @_;
     my $file           = $parameters{ file };
     my $sep_char       = $parameters{ sep_char } // ',';
+    my $quote_char     = $parameters{ quote_char } // '"';
     my $encoding       = $parameters{ encoding } // 'iso-8859-1';
     my $originalHeader = $parameters{ originalHeader };
     my $retorno        = { rows => undef, error => 0, message => undef, };
@@ -461,6 +462,7 @@ sub parseCSV()
                 blank_is_undef => 1,
                 empty_is_undef => 1,
                 sep_char       => $sep_char,
+                quote_char     => $quote_char,
             }
         );
 
